@@ -1,11 +1,13 @@
 #include "ex.h"
 #include <qpthr/qp.h>
 
+__USE_QPTHR_NAMESPACE
+
 class MyException: public QpUserException 
 {
     public:
 	MyException(int code = 0, const char *text = NULL): QpUserException(code, text) {} 
-	virtual QpClonedException *MyException::Clone() const {
+	virtual QpClonedException *Clone() const {
 		return new MyException(e_code, e_text);
 	}
 	virtual void Raise() const { throw *this;}
