@@ -1,6 +1,8 @@
-#include <iostream.h>
+#include "ex.h"
 #include <qpthr/qp.h>
 
+__USE_QPTHR_NAMESPACE
+
 class HelloWorld: public QpThread {
     public:
 	~HelloWorld() {Join();}
