@@ -1,9 +1,11 @@
-#include <iostream.h>
+#include "ex.h"
 #include <qpthr/qp.h>
 
-class HelloWorld: public QpRunnable {
+__USE_QPTHR_NAMESPACE
+
+class HelloWorldRun: public QpRunnable {
     public:
-	void Main() {
+	virtual void Main() {
 		cout << "Hello World" << endl;
 	}
 };
@@ -12,7 +14,7 @@ class HelloWorld: public QpRunnable {
 int main()
 {
 	QpInit qp_init;
-	HelloWorld hw;
+	HelloWorldRun hw;
 	QpThread t(&hw);
 	
 	t.Start();
