@@ -1,9 +1,10 @@
 #include "ex.h"
 #include <qpthr/qp.h>
 
+__USE_QPTHR_NAMESPACE
 
 typedef QpStack< vector< int > > MsgStack;
-static int verbose = 0;
+/*static*/ int verbose = 0;
 
 class Producer: public QpThread
 {
