@@ -1,6 +1,7 @@
-#include <iostream.h>
+#include "ex.h"
 #include <qpthr/qp.h>
 
+__USE_QPTHR_NAMESPACE
 
 class PerThreadObject {
     public:
@@ -18,7 +19,7 @@ class TsdtThread: public QpThread {
 	virtual ~TsdtThread() {Join();}
 	virtual void Main() {
 		tsd->Invoke();
-		sleep(1);
+		QpThread::Sleep(1);
 	}
 };
 
