@@ -8,6 +8,8 @@
  */
 #include <qpthr/qp.h>
 
+__BEGIN_QPTHR_NAMESPACE
+
 /*
  * 
  * QpOnce
@@ -89,3 +91,5 @@ void QpTSD::Set(void *arg)
 	QPERR(pthread_setspecific(ts_key, arg));
 }
 
+__END_QPTHR_NAMESPACE
+
