@@ -63,6 +63,11 @@ static void sigsyncdelset(sigset_t *set)
 }
 #endif
 
+__BEGIN_QPTHR_NAMESPACE
+#ifdef  __SUPPORT_NAMESPACES
+using ::sigaction;
+#endif
+
 /*
  * 
  * QpStackReg
@@ -180,7 +185,7 @@ const unsigned int 	QpSignal::REG_SIG_MAGIC = 0xAADD4423;
 QpSignal::QpSignalThread *QpSignal::s_sig_thread;
 int			QpSignal::s_req_pipe[2];
 
-static void CheckCapability(char *msg)
+static void CheckCapability(const char *msg)
 {
 	if (!QpInit::Capability(QpInit::QP_SIGNAL))
 		throw QpErrorException(QP_ERROR_DISABLED, msg);
@@ -644,3 +649,5 @@ QpThread *QpSignal::SignalThread()
 }
 
 #endif
+
+__END_QPTHR_NAMESPACE
