@@ -13,7 +13,9 @@
 #endif
 #include <qpthr/qp.h>
 
-static inline void CheckCapability(char *msg)
+__BEGIN_QPTHR_NAMESPACE
+
+static inline void CheckCapability(const char *msg)
 {
 	if (!QpInit::Initialized()) {
 		throw QpErrorException(QP_ERROR_DISABLED, msg);
@@ -366,9 +368,7 @@ unsigned long QpThread::CurrentSeq()
 {
 #ifdef OSF1
 	return pthread_getsequence_np(pthread_self());
-#elif WIN32  // JBR
-	return reinterpret_cast<unsigned long>(pthread_self());
-#elif FREEBSD	
+#elif defined(WIN32) || defined(FREEBSD)
 	return reinterpret_cast<unsigned long>(pthread_self());
 #else
 	return pthread_self();
@@ -379,9 +379,7 @@ unsigned long QpThread::ThreadSeq()
 {
 #ifdef OSF1
 	return pthread_getsequence_np(t_id);
-#elif WIN32 // JBR
-  	return reinterpret_cast<unsigned long>(t_id);
-#elif FREEBSD	
+#elif defined(WIN32) || defined(FREEBSD)
   	return reinterpret_cast<unsigned long>(t_id);
 #else
 	return t_id;
@@ -397,8 +395,12 @@ unsigned int QpThread::SetPriority(unsigned int prio)
 	CheckCapability("QpThread::SetPriority");
 	if (prio == QP_PRIO_DFL)
 		return t_prio_old;
-	if (prio > QP_PRIO_MAX)
-		throw QpErrorException(QP_ERROR_ARG, "SetPriority");
+	if (prio > QP_PRIO_MAX) {
+		if (prio < QP_PRIO_OFFSET + QpInit::PrioValue(QP_PRIO_MIN) ||
+		    prio > QP_PRIO_OFFSET + QpInit::PrioValue(QP_PRIO_MAX)) {
+			throw QpErrorException(QP_ERROR_ARG, "SetPriority");
+		}
+	}
 	policy = QpInit::DflSchedPolicy();
 	QpInit::AdjustSchedParam(prio, &sch_attr);
 	QpSLock lock(&t_mutex);
@@ -637,3 +639,5 @@ int QpThreadPool::CurrentThreads()
 	return p_threads.size();
 }
 
+__END_QPTHR_NAMESPACE
+
