@@ -9,6 +9,8 @@
 #ifndef __QP_WORK_H
 #define __QP_WORK_H
 
+__BEGIN_QPTHR_NAMESPACE
+
 /*
  * 
  * Jobs executing procedures
@@ -721,5 +723,7 @@ class QpWork_mcf5: public QpRunnable {
 	virtual void Main() {m_result = (m_obj->*m_mfn5)(m_p1, m_p2, m_p3, m_p4, m_p5);}
 };
 
+__END_QPTHR_NAMESPACE
+
 #endif
 
